@@ -259,26 +259,26 @@
 #include "vector"
 // ./core/clingutils/G__setDict.cxx
 #include "set"
-// ./core/clingutils/G__multisetDict.cxx
-#include "set"
 // ./core/clingutils/G__multimap2Dict.cxx
 #include "map"
+// ./core/clingutils/G__multisetDict.cxx
+#include "set"
 // ./core/clingutils/G__multimapDict.cxx
 #include "map"
 // ./core/clingutils/G__map2Dict.cxx
 #include "map"
-// ./core/clingutils/G__mapDict.cxx
-#include "map"
 // ./core/clingutils/G__unordered_setDict.cxx
 #include "unordered_set"
 // ./core/clingutils/G__unordered_multisetDict.cxx
 #include "unordered_set"
+// ./core/clingutils/G__mapDict.cxx
+#include "map"
 // ./core/clingutils/G__valarrayDict.cxx
 #include "valarray"
-// ./core/clingutils/G__complexDict.cxx
-#include "root_std_complex.h"
 // ./core/clingutils/G__unordered_multimapDict.cxx
 #include "unordered_map"
+// ./core/clingutils/G__complexDict.cxx
+#include "root_std_complex.h"
 // ./core/clingutils/G__unordered_mapDict.cxx
 #include "unordered_map"
 // ./core/imt/G__Imt.cxx
@@ -496,10 +496,6 @@
 #include "TMinuit.h"
 #include "TMinuitMinimizer.h"
 // ./math/minuit2/G__Minuit2.cxx
-#include "Minuit2/ABObj.h"
-#include "Minuit2/ABProd.h"
-#include "Minuit2/ABSum.h"
-#include "Minuit2/ABTypes.h"
 #include "Minuit2/AnalyticalGradientCalculator.h"
 #include "Minuit2/BFGSErrorUpdator.h"
 #include "Minuit2/CombinedMinimizer.h"
@@ -523,18 +519,9 @@
 #include "Minuit2/FumiliStandardMaximumLikelihoodFCN.h"
 #include "Minuit2/FunctionGradient.h"
 #include "Minuit2/FunctionMinimum.h"
-#include "Minuit2/GenericFunction.h"
 #include "Minuit2/GradientCalculator.h"
 #include "Minuit2/HessianGradientCalculator.h"
 #include "Minuit2/InitialGradientCalculator.h"
-#include "Minuit2/LASymMatrix.h"
-#include "Minuit2/LAVector.h"
-#include "Minuit2/LaInverse.h"
-#include "Minuit2/LaOuterProduct.h"
-#include "Minuit2/LaProd.h"
-#include "Minuit2/LaSum.h"
-#include "Minuit2/MPIProcess.h"
-#include "Minuit2/MatrixInverse.h"
 #include "Minuit2/MinimumBuilder.h"
 #include "Minuit2/MinimumError.h"
 #include "Minuit2/MinimumErrorUpdator.h"
@@ -581,7 +568,6 @@
 #include "Minuit2/MnUserParameterState.h"
 #include "Minuit2/MnUserParameters.h"
 #include "Minuit2/MnUserTransformation.h"
-#include "Minuit2/MnVectorTransform.h"
 #include "Minuit2/ModularFunctionMinimizer.h"
 #include "Minuit2/NegativeG2LineSearch.h"
 #include "Minuit2/Numerical2PGradientCalculator.h"
@@ -596,11 +582,9 @@
 #include "Minuit2/SinParameterTransformation.h"
 #include "Minuit2/SqrtLowParameterTransformation.h"
 #include "Minuit2/SqrtUpParameterTransformation.h"
-#include "Minuit2/StackAllocator.h"
 #include "Minuit2/VariableMetricBuilder.h"
 #include "Minuit2/VariableMetricEDMEstimator.h"
 #include "Minuit2/VariableMetricMinimizer.h"
-#include "Minuit2/VectorOuterProduct.h"
 #include "TMinuit2TraceObject.h"
 // ./math/physics/G__Physics.cxx
 #include "TFeldmanCousins.h"
@@ -855,21 +839,6 @@
 #include "TGraphPainter.h"
 #include "THistPainter.h"
 #include "TPaletteAxis.h"
-// ./hist/histv7/G__ROOTHist.cxx
-#include "ROOT/RAxis.hxx"
-#include "ROOT/RAxisConfig.hxx"
-#include "ROOT/RHist.hxx"
-#include "ROOT/RHistBinIter.hxx"
-#include "ROOT/RHistBufferedFill.hxx"
-#include "ROOT/RHistConcurrentFill.hxx"
-#include "ROOT/RHistData.hxx"
-#include "ROOT/RHistImpl.hxx"
-#include "ROOT/RHistUtils.hxx"
-#include "ROOT/RHistView.hxx"
-// ./hist/histdrawv7/G__ROOTHistDraw.cxx
-#include "ROOT/RHistDisplayItem.hxx"
-#include "ROOT/RHistDrawable.hxx"
-#include "ROOT/RHistStatBox.hxx"
 // ./hist/spectrum/G__Spectrum.cxx
 #include "TSpectrum.h"
 #include "TSpectrum2.h"
@@ -1001,6 +970,7 @@
 #include "ROOT/RRootDS.hxx"
 #include "ROOT/RSnapshotOptions.hxx"
 #include "ROOT/RTrivialDS.hxx"
+#include "ROOT/RTTreeDS.hxx"
 #include "ROOT/RDF/ActionHelpers.hxx"
 #include "ROOT/RDF/ColumnReaderUtils.hxx"
 #include "ROOT/RDF/GraphNode.hxx"
@@ -1050,8 +1020,8 @@
 #include "ROOT/RDF/Utils.hxx"
 #include "ROOT/RDF/PyROOTHelpers.hxx"
 #include "ROOT/RDF/RDFDescription.hxx"
-#include "ROOT/RSqliteDS.hxx"
 #include "ROOT/RNTupleDS.hxx"
+#include "ROOT/RSqliteDS.hxx"
 // ./tree/ntuple/G__ROOTNTuple.cxx
 #include "ROOT/RCluster.hxx"
 #include "ROOT/RClusterPool.hxx"
@@ -1060,6 +1030,8 @@
 #include "ROOT/REntry.hxx"
 #include "ROOT/RField.hxx"
 #include "ROOT/RFieldBase.hxx"
+#include "ROOT/RFieldToken.hxx"
+#include "ROOT/RFieldUtils.hxx"
 #include "ROOT/RFieldVisitor.hxx"
 #include "ROOT/RMiniFile.hxx"
 #include "ROOT/RNTuple.hxx"
@@ -1067,12 +1039,13 @@
 #include "ROOT/RNTupleFillContext.hxx"
 #include "ROOT/RNTupleFillStatus.hxx"
 #include "ROOT/RNTupleImtTaskScheduler.hxx"
-#include "ROOT/RNTupleIndex.hxx"
+#include "ROOT/RNTupleJoinTable.hxx"
 #include "ROOT/RNTupleMerger.hxx"
 #include "ROOT/RNTupleMetrics.hxx"
 #include "ROOT/RNTupleModel.hxx"
 #include "ROOT/RNTupleParallelWriter.hxx"
 #include "ROOT/RNTupleProcessor.hxx"
+#include "ROOT/RNTupleRange.hxx"
 #include "ROOT/RNTupleReadOptions.hxx"
 #include "ROOT/RNTupleReader.hxx"
 #include "ROOT/RNTupleSerialize.hxx"
@@ -1087,11 +1060,12 @@
 #include "ROOT/RPageNullSink.hxx"
 #include "ROOT/RPagePool.hxx"
 #include "ROOT/RPageSinkBuf.hxx"
-#include "ROOT/RPageSourceFriends.hxx"
 #include "ROOT/RPageStorage.hxx"
 #include "ROOT/RPageStorageFile.hxx"
+#include "ROOT/RRawPtrWriteEntry.hxx"
 // ./tree/ntupleutil/G__ROOTNTupleUtil.cxx
 #include "ROOT/RNTupleImporter.hxx"
+#include "ROOT/RNTupleExporter.hxx"
 #include "ROOT/RNTupleInspector.hxx"
 // ./io/io/G__RIO.cxx
 #include "ROOT/RRawFile.hxx"
@@ -1128,7 +1102,6 @@
 #include "TVirtualCollectionIterators.h"
 #include "TStreamerInfo.h"
 #include "TZIPFile.h"
-#include "ROOT/RFile.hxx"
 // ./net/net/G__Net.cxx
 #include "NetErrors.h"
 #include "RRemoteProtocol.h"
@@ -1782,6 +1755,12 @@
 #include "TMVA/ROperator_TopK.hxx"
 #include "TMVA/ROperator_Tile.hxx"
 #include "TMVA/ROperator_Split.hxx"
+#include "TMVA/ROperator_SubGraph.hxx"
+#include "TMVA/ROperator_Pad.hxx"
+#include "TMVA/ROperator_Where.hxx"
+#include "TMVA/ROperator_Einsum.hxx"
+#include "TMVA/ROperator_Random.hxx"
+#include "TMVA/ROperator_ScatterElements.hxx"
 #include "TMVA/SOFIE_common.hxx"
 #include "TMVA/SOFIEHelpers.hxx"
 #include "TMVA/FunctionList.hxx"
@@ -1791,6 +1770,8 @@
 #include "TMVA/RFunction_MLP.hxx"
 #include "TMVA/RFunction_Sum.hxx"
 #include "TMVA/RFunction_Mean.hxx"
+// ./roofit/codegen/G__RooFitCodegen.cxx
+#include "RooFit/CodegenImpl.h"
 // ./roofit/roofitcore/G__RooFitCore.cxx
 #include "Roo1DTable.h"
 #include "RooAICRegistry.h"
@@ -1873,8 +1854,8 @@
 #include "RooFactoryWSTool.h"
 #include "RooFirstMoment.h"
 #include "RooFit.h"
+#include "RooFit/CodegenContext.h"
 #include "RooFit/Config.h"
-#include "RooFit/Detail/CodeSquashContext.h"
 #include "RooFit/Detail/MathFuncs.h"
 #include "RooFit/Detail/NormalizationHelpers.h"
 #include "RooFit/Detail/RooNLLVarNew.h"
@@ -1891,8 +1872,8 @@
 #include "RooFit/TestStatistics/RooSubsidiaryL.h"
 #include "RooFit/TestStatistics/RooSumL.h"
 #include "RooFit/TestStatistics/RooUnbinnedL.h"
-#include "RooFit/TestStatistics/buildLikelihood.h"
 #include "RooFit/TestStatistics/SharedOffset.h"
+#include "RooFit/TestStatistics/buildLikelihood.h"
 #include "RooFitLegacy/RooCatTypeLegacy.h"
 #include "RooFitLegacy/RooCategorySharedProperties.h"
 #include "RooFitLegacy/RooTreeData.h"
@@ -1948,7 +1929,6 @@
 #include "RooProduct.h"
 #include "RooProfileLL.h"
 #include "RooProjectedPdf.h"
-#include "RooProofDriverSelector.h"
 #include "RooPullVar.h"
 #include "RooQuasiRandomGenerator.h"
 #include "RooRandom.h"
@@ -2097,7 +2077,6 @@
 #include "RooStats/MCMCInterval.h"
 #include "RooStats/MCMCIntervalPlot.h"
 #include "RooStats/MetropolisHastings.h"
-#include "RooStats/MinNLLTestStat.h"
 #include "RooStats/ModelConfig.h"
 #include "RooStats/NeymanConstruction.h"
 #include "RooStats/NumberCountingPdfFactory.h"
@@ -2108,7 +2087,6 @@
 #include "RooStats/ProfileInspector.h"
 #include "RooStats/ProfileLikelihoodCalculator.h"
 #include "RooStats/ProfileLikelihoodTestStat.h"
-#include "RooStats/ProofConfig.h"
 #include "RooStats/ProposalFunction.h"
 #include "RooStats/ProposalHelper.h"
 #include "RooStats/RatioOfProfiledLikelihoodsTestStat.h"
@@ -2123,7 +2101,6 @@
 #include "RooStats/TestStatSampler.h"
 #include "RooStats/ToyMCImportanceSampler.h"
 #include "RooStats/ToyMCSampler.h"
-#include "RooStats/ToyMCStudy.h"
 #include "RooStats/UniformProposal.h"
 #include "RooStats/UpperLimitMCSModule.h"
 // ./roofit/histfactory/G__HistFactory.cxx
@@ -2161,6 +2138,7 @@
 #include "RooFit/xRooFit/xRooHypoSpace.h"
 #include "RooFit/xRooFit/xRooBrowser.h"
 // ./core/G__Core.cxx
+#include "ROOT/RFloat16.hxx"
 #include "ROOT/TErrorDefaultHandler.hxx"
 #include "ROOT/TExecutorCRTP.hxx"
 #include "ROOT/TSequentialExecutor.hxx"
@@ -2258,9 +2236,6 @@
 #include "TVirtualTableInterface.h"
 #include "TVirtualViewer3D.h"
 #include "TVirtualX.h"
-#include "ROOT/RFloat16.hxx"
-#include "ROOT/RDirectoryEntry.hxx"
-#include "ROOT/RIndexIter.hxx"
 #include "strlcpy.h"
 #include "snprintf.h"
 #include "strtok.h"
@@ -2299,6 +2274,7 @@
 #include "TClassEdit.h"
 #include "TError.h"
 #include "ThreadLocalStorage.h"
+#include "ROOT/RError.hxx"
 #include "ROOT/RLogger.hxx"
 #include "ROOT/RNotFn.hxx"
 #include "ROOT/RRangeCast.hxx"
@@ -2307,7 +2283,6 @@
 #include "ROOT/StringUtils.hxx"
 #include "ROOT/span.hxx"
 #include "ROOT/TypeTraits.hxx"
-#include "ROOT/RError.hxx"
 #include "GuiTypes.h"
 #include "TApplicationImp.h"
 #include "TBrowser.h"
